@@ -21,10 +21,10 @@ from neutron.db import common_db_mixin as base_db
 from neutron.db import l3_agentschedulers_db as l3_agent_db
 from neutron.db import models_v2
 from neutron.extensions import l3 as l3_exception
-from neutron import manager
 from neutron.plugins.common import constants as p_constants
 from neutron.plugins.common import utils
 from neutron_lib import constants as lib_constants
+from neutron_lib.plugins import directory
 from oslo_log import log as logging
 from oslo_utils import excutils
 from oslo_utils import uuidutils
@@ -312,11 +312,13 @@ class VPNPluginDb(vpnaas.VPNPluginBase,
 
     def create_ikepolicy(self, context, ikepolicy):
         ike = ikepolicy['ikepolicy']
+        validator = self._get_validator()
         lifetime_info = ike['lifetime']
         lifetime_units = lifetime_info.get('units', 'seconds')
         lifetime_value = lifetime_info.get('value', 3600)
 
         with context.session.begin(subtransactions=True):
+            validator.validate_ike_policy(context, ike)
             ike_db = vpn_models.IKEPolicy(
                 id=uuidutils.generate_uuid(),
                 tenant_id=ike['tenant_id'],
@@ -336,7 +338,9 @@ class VPNPluginDb(vpnaas.VPNPluginBase,
 
     def update_ikepolicy(self, context, ikepolicy_id, ikepolicy):
         ike = ikepolicy['ikepolicy']
+        validator = self._get_validator()
         with context.session.begin(subtransactions=True):
+            validator.validate_ike_policy(context, ike)
             if context.session.query(vpn_models.IPsecSiteConnection).filter_by(
                     ikepolicy_id=ikepolicy_id).first():
                 raise vpnaas.IKEPolicyInUse(ikepolicy_id=ikepolicy_id)
@@ -635,7 +639,7 @@ class VPNPluginDb(vpnaas.VPNPluginBase,
 class VPNPluginRpcDbMixin(object):
     def _get_agent_hosting_vpn_services(self, context, host):
 
-        plugin = manager.NeutronManager.get_plugin()
+        plugin = directory.get_plugin()
         agent = plugin._get_agent_by_type_and_host(
             context, lib_constants.AGENT_TYPE_L3, host)
         agent_conf = plugin.get_configuration_dict(agent)
@@ -709,8 +713,7 @@ class VPNPluginRpcDbMixin(object):
 
 
 def vpn_callback(resource, event, trigger, **kwargs):
-    vpn_plugin = manager.NeutronManager.get_service_plugins().get(
-        p_constants.VPN)
+    vpn_plugin = directory.get_plugin(p_constants.VPN)
     if vpn_plugin:
         context = kwargs.get('context')
         if resource == resources.ROUTER_GATEWAY:
@@ -725,8 +728,7 @@ def vpn_callback(resource, event, trigger, **kwargs):
 def migration_callback(resource, event, trigger, **kwargs):
     context = kwargs['context']
     router = kwargs['router']
-    vpn_plugin = manager.NeutronManager.get_service_plugins().get(
-        p_constants.VPN)
+    vpn_plugin = directory.get_plugin(p_constants.VPN)
     if vpn_plugin:
         vpn_plugin.check_router_in_use(context, router['id'])
     return True
@@ -736,8 +738,7 @@ def subnet_callback(resource, event, trigger, **kwargs):
     """Respond to subnet based notifications - see if subnet in use."""
     context = kwargs['context']
     subnet_id = kwargs['subnet_id']
-    vpn_plugin = manager.NeutronManager.get_service_plugins().get(
-        p_constants.VPN)
+    vpn_plugin = directory.get_plugin(p_constants.VPN)
     if vpn_plugin:
         vpn_plugin.check_subnet_in_use_by_endpoint_group(context, subnet_id)
 
