@@ -17,10 +17,10 @@ import socket
 
 from neutron.db import l3_db
 from neutron.db import models_v2
-from neutron import manager
-from neutron.plugins.common import constants as nconstants
 from neutron_lib.api import validators
+from neutron_lib import constants as const
 from neutron_lib import exceptions as nexception
+from neutron_lib.plugins import directory
 
 from neutron_vpnaas._i18n import _
 from neutron_vpnaas.extensions import vpnaas
@@ -38,8 +38,7 @@ class VpnReferenceValidator(object):
         try:
             return self._l3_plugin
         except AttributeError:
-            self._l3_plugin = manager.NeutronManager.get_service_plugins().get(
-                nconstants.L3_ROUTER_NAT)
+            self._l3_plugin = directory.get_plugin(const.L3)
             return self._l3_plugin
 
     @property
@@ -47,7 +46,7 @@ class VpnReferenceValidator(object):
         try:
             return self._core_plugin
         except AttributeError:
-            self._core_plugin = manager.NeutronManager.get_plugin()
+            self._core_plugin = directory.get_plugin()
             return self._core_plugin
 
     def _check_dpd(self, ipsec_sitecon):
@@ -131,6 +130,14 @@ class VpnReferenceValidator(object):
             raise vpnaas.MixedIPVersionsForIPSecEndpoints(group=group_id)
         return ip_versions.pop()
 
+    def _check_peer_cidrs(self, peer_cidrs):
+        """Ensure all CIDRs have the valid format."""
+        for peer_cidr in peer_cidrs:
+            msg = validators.validate_subnet(peer_cidr)
+            if msg:
+                raise vpnaas.IPsecSiteConnectionPeerCidrError(
+                    peer_cidr=peer_cidr)
+
     def _check_peer_cidrs_ip_versions(self, peer_cidrs):
         """Ensure all CIDRs have the same IP version."""
         if len(peer_cidrs) == 1:
@@ -231,8 +238,8 @@ class VpnReferenceValidator(object):
         For legacy mode, we use the (sole) subnet IP version, and the peer
         CIDR(s). All IP versions must be the same.
 
-        This method also checks MTU (based on the local IP version), and
-        DPD settings.
+        This method also checks peer_cidrs format(legacy mode),
+        MTU (based on the local IP version), and DPD settings.
         """
         if not local_ip_version:
             # Using endpoint groups
@@ -246,6 +253,7 @@ class VpnReferenceValidator(object):
             peer_ip_version = self._check_peer_endpoint_ip_versions(
                 ipsec_sitecon['peer_ep_group_id'], peer_cidrs)
         else:
+            self._check_peer_cidrs(ipsec_sitecon['peer_cidrs'])
             peer_ip_version = self._check_peer_cidrs_ip_versions(
                 ipsec_sitecon['peer_cidrs'])
         self._validate_compatible_ip_versions(local_ip_version,
@@ -324,3 +332,11 @@ class VpnReferenceValidator(object):
             self._validate_cidrs(endpoints)
         elif group_type == constants.SUBNET_ENDPOINT:
             self._validate_subnets(context, endpoints)
+
+    def validate_ike_policy(self, context, ike_policy):
+        """Reference implementation of validation for IKE Policy.
+
+        Service driver can override and implement specific logic
+        for IKE Policy validation.
+        """
+        pass
