@@ -15,14 +15,16 @@
 
 import abc
 
+from neutron_lib.api import converters
+from neutron_lib.api import extensions
+from neutron_lib.api import validators as validators
+from neutron_lib.db import constants as db_const
+from neutron_lib import exceptions as nexception
 import six
 
-from neutron.api import extensions
-from neutron.api.v2 import attributes as attr
 from neutron.api.v2 import resource_helper
 from neutron.plugins.common import constants as nconstants
 from neutron.services import service_base
-from neutron_lib import exceptions as nexception
 
 from neutron_vpnaas._i18n import _
 
@@ -45,6 +47,11 @@ class IPsecSiteConnectionMtuError(nexception.InvalidInput):
                 "for ipv%(version)s")
 
 
+class IPsecSiteConnectionPeerCidrError(nexception.InvalidInput):
+    message = _("ipsec_site_connection peer cidr %(peer_cidr)s is "
+                "invalid CIDR")
+
+
 class IKEPolicyNotFound(nexception.NotFound):
     message = _("IKEPolicy %(ikepolicy_id)s could not be found")
 
@@ -164,9 +171,10 @@ class EndpointGroupInUse(nexception.BadRequest):
 
 def _validate_subnet_list_or_none(data, key_specs=None):
     if data is not None:
-        attr._validate_subnet_list(data, key_specs)
+        return validators.validate_subnet_list(data, key_specs)
 
-attr.validators['type:subnet_list_or_none'] = _validate_subnet_list_or_none
+validators.add_validator('type:subnet_list_or_none',
+                        _validate_subnet_list_or_none)
 
 vpn_supported_initiators = ['bi-directional', 'response-only']
 vpn_supported_encryption_algorithms = ['3des', 'aes-128',
@@ -181,11 +189,11 @@ vpn_supported_lifetime_units = ['seconds']
 vpn_supported_pfs = ['group2', 'group5', 'group14']
 vpn_supported_ike_versions = ['v1', 'v2']
 vpn_supported_auth_mode = ['psk']
-vpn_supported_auth_algorithms = ['sha1']
+vpn_supported_auth_algorithms = ['sha1', 'sha256', 'sha384', 'sha512']
 vpn_supported_phase1_negotiation_mode = ['main']
 
-vpn_lifetime_limits = (60, attr.UNLIMITED)
-positive_int = (0, attr.UNLIMITED)
+vpn_lifetime_limits = (60, validators.UNLIMITED)
+positive_int = (0, validators.UNLIMITED)
 
 RESOURCE_ATTRIBUTE_MAP = {
 
@@ -195,14 +203,16 @@ RESOURCE_ATTRIBUTE_MAP = {
                'is_visible': True,
                'primary_key': True},
         'tenant_id': {'allow_post': True, 'allow_put': False,
-                      'validate': {'type:string': None},
+                      'validate': {
+                          'type:string': db_const.PROJECT_ID_FIELD_SIZE},
                       'required_by_policy': True,
                       'is_visible': True},
         'name': {'allow_post': True, 'allow_put': True,
-                 'validate': {'type:string': attr.NAME_MAX_LEN},
+                 'validate': {'type:string': db_const.NAME_FIELD_SIZE},
                  'is_visible': True, 'default': ''},
         'description': {'allow_post': True, 'allow_put': True,
-                        'validate': {'type:string': attr.DESCRIPTION_MAX_LEN},
+                        'validate': {
+                            'type:string': db_const.DESCRIPTION_FIELD_SIZE},
                         'is_visible': True, 'default': ''},
         'subnet_id': {'allow_post': True, 'allow_put': False,
                       'validate': {'type:uuid_or_none': None},
@@ -212,7 +222,7 @@ RESOURCE_ATTRIBUTE_MAP = {
                       'is_visible': True},
         'admin_state_up': {'allow_post': True, 'allow_put': True,
                            'default': True,
-                           'convert_to': attr.convert_to_boolean,
+                           'convert_to': converters.convert_to_boolean,
                            'is_visible': True},
         'external_v4_ip': {'allow_post': False, 'allow_put': False,
                         'is_visible': True},
@@ -228,15 +238,20 @@ RESOURCE_ATTRIBUTE_MAP = {
                'is_visible': True,
                'primary_key': True},
         'tenant_id': {'allow_post': True, 'allow_put': False,
-                      'validate': {'type:string': None},
+                      'validate': {
+                          'type:string': db_const.PROJECT_ID_FIELD_SIZE},
                       'required_by_policy': True,
                       'is_visible': True},
         'name': {'allow_post': True, 'allow_put': True,
-                 'validate': {'type:string': attr.NAME_MAX_LEN},
+                 'validate': {'type:string': db_const.NAME_FIELD_SIZE},
                  'is_visible': True, 'default': ''},
         'description': {'allow_post': True, 'allow_put': True,
-                        'validate': {'type:string': attr.DESCRIPTION_MAX_LEN},
+                        'validate': {
+                            'type:string': db_const.DESCRIPTION_FIELD_SIZE},
                         'is_visible': True, 'default': ''},
+        'local_id': {'allow_post': True, 'allow_put': True,
+                    'validate': {'type:string': None},
+                    'is_visible': True, 'default': ''},
         'peer_address': {'allow_post': True, 'allow_put': True,
                          'validate': {'type:string': None},
                          'is_visible': True},
@@ -244,7 +259,7 @@ RESOURCE_ATTRIBUTE_MAP = {
                     'validate': {'type:string': None},
                     'is_visible': True},
         'peer_cidrs': {'allow_post': True, 'allow_put': True,
-                       'convert_to': attr.convert_to_list,
+                       'convert_to': converters.convert_to_list,
                        'validate': {'type:subnet_list_or_none': None},
                        'is_visible': True,
                        'default': None},
@@ -260,7 +275,7 @@ RESOURCE_ATTRIBUTE_MAP = {
         'mtu': {'allow_post': True, 'allow_put': True,
                 'default': '1500',
                 'validate': {'type:range': positive_int},
-                'convert_to': attr.convert_to_int,
+                'convert_to': converters.convert_to_int,
                 'is_visible': True},
         'initiator': {'allow_post': True, 'allow_put': True,
                       'default': 'bi-directional',
@@ -274,12 +289,12 @@ RESOURCE_ATTRIBUTE_MAP = {
                 'validate': {'type:string': None},
                 'is_visible': True},
         'dpd': {'allow_post': True, 'allow_put': True,
-                'convert_to': attr.convert_none_to_empty_dict,
+                'convert_to': converters.convert_none_to_empty_dict,
                 'is_visible': True,
                 'default': {},
                 'validate': {
                     'type:dict_or_empty': {
-                        'actions': {
+                        'action': {
                             'type:values': vpn_dpd_supported_actions,
                         },
                         'interval': {
@@ -290,7 +305,7 @@ RESOURCE_ATTRIBUTE_MAP = {
                         }}}},
         'admin_state_up': {'allow_post': True, 'allow_put': True,
                            'default': True,
-                           'convert_to': attr.convert_to_boolean,
+                           'convert_to': converters.convert_to_boolean,
                            'is_visible': True},
         'status': {'allow_post': False, 'allow_put': False,
                    'is_visible': True},
@@ -311,14 +326,16 @@ RESOURCE_ATTRIBUTE_MAP = {
                'is_visible': True,
                'primary_key': True},
         'tenant_id': {'allow_post': True, 'allow_put': False,
-                      'validate': {'type:string': None},
+                      'validate': {
+                          'type:string': db_const.PROJECT_ID_FIELD_SIZE},
                       'required_by_policy': True,
                       'is_visible': True},
         'name': {'allow_post': True, 'allow_put': True,
-                 'validate': {'type:string': attr.NAME_MAX_LEN},
+                 'validate': {'type:string': db_const.NAME_FIELD_SIZE},
                  'is_visible': True, 'default': ''},
         'description': {'allow_post': True, 'allow_put': True,
-                        'validate': {'type:string': attr.DESCRIPTION_MAX_LEN},
+                        'validate': {
+                            'type:string': db_const.DESCRIPTION_FIELD_SIZE},
                         'is_visible': True, 'default': ''},
         'transform_protocol': {
             'allow_post': True,
@@ -352,7 +369,7 @@ RESOURCE_ATTRIBUTE_MAP = {
             },
             'is_visible': True},
         'lifetime': {'allow_post': True, 'allow_put': True,
-                     'convert_to': attr.convert_none_to_empty_dict,
+                     'convert_to': converters.convert_none_to_empty_dict,
                      'default': {},
                      'validate': {
                          'type:dict_or_empty': {
@@ -375,14 +392,16 @@ RESOURCE_ATTRIBUTE_MAP = {
                'is_visible': True,
                'primary_key': True},
         'tenant_id': {'allow_post': True, 'allow_put': False,
-                      'validate': {'type:string': None},
+                      'validate': {
+                          'type:string': db_const.PROJECT_ID_FIELD_SIZE},
                       'required_by_policy': True,
                       'is_visible': True},
         'name': {'allow_post': True, 'allow_put': True,
-                 'validate': {'type:string': attr.NAME_MAX_LEN},
+                 'validate': {'type:string': db_const.NAME_FIELD_SIZE},
                  'is_visible': True, 'default': ''},
         'description': {'allow_post': True, 'allow_put': True,
-                        'validate': {'type:string': attr.DESCRIPTION_MAX_LEN},
+                        'validate': {
+                            'type:string': db_const.DESCRIPTION_FIELD_SIZE},
                         'is_visible': True, 'default': ''},
         'auth_algorithm': {'allow_post': True, 'allow_put': True,
                            'default': 'sha1',
@@ -402,7 +421,7 @@ RESOURCE_ATTRIBUTE_MAP = {
             },
             'is_visible': True},
         'lifetime': {'allow_post': True, 'allow_put': True,
-                     'convert_to': attr.convert_none_to_empty_dict,
+                     'convert_to': converters.convert_none_to_empty_dict,
                      'default': {},
                      'validate': {
                          'type:dict_or_empty': {
@@ -455,7 +474,6 @@ class Vpnaas(extensions.ExtensionDescriptor):
         plural_mappings = resource_helper.build_plural_mappings(
             special_mappings, RESOURCE_ATTRIBUTE_MAP)
         plural_mappings['peer_cidrs'] = 'peer_cidr'
-        attr.PLURALS.update(plural_mappings)
         return resource_helper.build_resource_info(plural_mappings,
                                                    RESOURCE_ATTRIBUTE_MAP,
                                                    nconstants.VPN,
