@@ -141,7 +141,7 @@ def execute_with_mount():
         LOG.error(_LE('Cannot run without netns, exiting'))
         return errno.EINVAL
 
-    for path, new_path in six.iteritems(conf.mount_paths):
+    for path, new_path in conf.mount_paths.items():
         if not os.path.isdir(new_path):
             # Sometimes all directories are not ready
             LOG.debug('%s is not directory', new_path)
