@@ -14,8 +14,10 @@
 #    under the License.
 import abc
 import copy
+import filecmp
 import os
 import re
+import shutil
 import six
 import socket
 
@@ -24,12 +26,12 @@ import jinja2
 import netaddr
 from neutron.agent.linux import ip_lib
 from neutron.agent.linux import utils as agent_utils
-from neutron.api.v2 import attributes
 from neutron.common import rpc as n_rpc
 from neutron.common import utils as n_utils
 from neutron import context
 from neutron.plugins.common import constants
 from neutron.plugins.common import utils as plugin_utils
+from neutron_lib.api import validators
 from oslo_concurrency import lockutils
 from oslo_config import cfg
 from oslo_log import log as logging
@@ -94,7 +96,11 @@ pluto_opts = [
                  default=1.5,
                  help=_('A factor to increase the retry interval for '
                         'each retry'),
-                 deprecated_group='libreswan')
+                 deprecated_group='libreswan'),
+    cfg.BoolOpt('restart_check_config',
+                default=False,
+                help=_('Enable this flag to avoid from unnecessary restart'),
+                deprecated_group='libreswan')
 ]
 
 cfg.CONF.register_opts(pluto_opts, 'pluto')
@@ -142,6 +148,7 @@ class BaseSwanProcess(object):
         "aes-128": "aes128",
         "aes-256": "aes256",
         "aes-192": "aes192",
+        "sha256": "sha2_256",
         "group2": "modp1024",
         "group5": "modp1536",
         "group14": "modp2048",
@@ -194,6 +201,9 @@ class BaseSwanProcess(object):
                         'pfs']:
                 self._dialect(ipsec_site_conn['ikepolicy'], key)
                 self._dialect(ipsec_site_conn['ipsecpolicy'], key)
+            if (('local_id' not in ipsec_site_conn.keys()) or
+                (not ipsec_site_conn['local_id'])):
+                ipsec_site_conn['local_id'] = ipsec_site_conn['external_ip']
 
     def update_vpnservice(self, vpnservice):
         self.vpnservice = vpnservice
@@ -417,6 +427,17 @@ class OpenSwanProcess(BaseSwanProcess):
             self.vpnservice,
             0o600)
 
+    def _copy_configs(self):
+        if not cfg.CONF.pluto.restart_check_config:
+            return
+        config_file_name = self._get_config_filename('ipsec.conf')
+        if os.path.isfile(config_file_name):
+            shutil.copyfile(config_file_name, config_file_name + '.old')
+        config_file_name = self._get_config_filename('ipsec.secrets')
+        if os.path.isfile(config_file_name):
+            shutil.copyfile(config_file_name, config_file_name + '.old')
+        os.chmod(config_file_name + '.old', 0o600)
+
     def _process_running(self):
         """Checks if process is still running."""
 
@@ -479,8 +500,32 @@ class OpenSwanProcess(BaseSwanProcess):
                               self.pid_path,
                               '--status'], extra_ok_codes=[1, 3])
 
+    def _config_changed(self):
+        secrets_file = os.path.join(
+            self.etc_dir, 'ipsec.secrets')
+        config_file = os.path.join(
+            self.etc_dir, 'ipsec.conf')
+
+        if not os.path.isfile(secrets_file + '.old'):
+            return True
+        if not os.path.isfile(config_file + '.old'):
+            return True
+
+        if not filecmp.cmp(secrets_file, secrets_file + '.old'):
+            return True
+        if not filecmp.cmp(config_file, config_file + '.old'):
+            return True
+
+        return False
+
     def restart(self):
         """Restart the process."""
+        should_be_restart = False
+        if self._config_changed() or not cfg.CONF.pluto.restart_check_config:
+            should_be_restart = True
+        if not should_be_restart:
+            return
+
         # stop() followed immediately by a start() runs the risk that the
         # current pluto daemon has not had a chance to shutdown. We check
         # the current process information to see if the daemon is still
@@ -511,7 +556,7 @@ class OpenSwanProcess(BaseSwanProcess):
 
     def _get_nexthop(self, address, connection_id):
         # check if address is an ip address or fqdn
-        invalid_ip_address = attributes._validate_ip_address(address)
+        invalid_ip_address = validators.validate_ip_address(address)
         if invalid_ip_address:
             ip_addr = self._resolve_fqdn(address)
             if not ip_addr:
@@ -615,6 +660,7 @@ class OpenSwanProcess(BaseSwanProcess):
                            '--asynchronous',
                            '--initiate'
                            ])
+        self._copy_configs()
 
     def get_established_connections(self):
         connections = []
