@@ -169,6 +169,8 @@ class BaseIPsecVPNDriver(service_drivers.VpnDriver):
         also converting parameter name for vpn agent driver
         """
         vpnservice_dict = dict(vpnservice)
+        # Populate tenant_id for RPC compat
+        vpnservice_dict['tenant_id'] = vpnservice_dict['project_id']
         vpnservice_dict['ipsec_site_connections'] = []
         if vpnservice.subnet:
             vpnservice_dict['subnet'] = dict(vpnservice.subnet)
@@ -188,9 +190,14 @@ class BaseIPsecVPNDriver(service_drivers.VpnDriver):
             ipsec_site_connection_dict = dict(ipsec_site_connection)
             try:
                 netaddr.IPAddress(ipsec_site_connection_dict['peer_id'])
+                if ipsec_site_connection_dict['local_id']:
+                    netaddr.IPAddress(ipsec_site_connection_dict['local_id'])
             except netaddr.core.AddrFormatError:
                 ipsec_site_connection_dict['peer_id'] = (
                     '@' + ipsec_site_connection_dict['peer_id'])
+                if ipsec_site_connection_dict['local_id']:
+                    ipsec_site_connection_dict['local_id'] = (
+                        '@' + ipsec_site_connection_dict['local_id'])
             ipsec_site_connection_dict['ikepolicy'] = dict(
                 ipsec_site_connection.ikepolicy)
             ipsec_site_connection_dict['ipsecpolicy'] = dict(
