@@ -20,7 +20,9 @@ from neutron import context as n_ctx
 from neutron.db import l3_db
 from neutron.db import servicetype_db as st_db
 from neutron.plugins.common import constants as nconstants
+from neutron_lib import constants as lconstants
 from neutron_lib import exceptions as nexception
+from neutron_lib.plugins import directory
 from oslo_utils import uuidutils
 from sqlalchemy.orm import query
 
@@ -74,12 +76,9 @@ class TestIPsecDriverValidation(base.BaseTestCase):
     def setUp(self):
         super(TestIPsecDriverValidation, self).setUp()
         self.l3_plugin = mock.Mock()
-        mock.patch(
-            'neutron.manager.NeutronManager.get_service_plugins',
-            return_value={nconstants.L3_ROUTER_NAT: self.l3_plugin}).start()
         self.core_plugin = mock.Mock()
-        mock.patch('neutron.manager.NeutronManager.get_plugin',
-                   return_value=self.core_plugin).start()
+        directory.add_plugin(lconstants.CORE, self.core_plugin)
+        directory.add_plugin(lconstants.L3, self.l3_plugin)
         self.context = n_ctx.Context('some_user', 'some_tenant')
         self.service_plugin = mock.Mock()
         self.validator = vpn_validator.IpsecVpnValidator(self.service_plugin)
@@ -201,11 +200,35 @@ class TestIPsecDriverValidation(base.BaseTestCase):
                                           expected_exception=True)
 
     def test_validate_ipsec_policy(self):
+        # Validate IPsec Policy transform_protocol and auth_algorithm
         ipsec_policy = {'transform_protocol': 'ah-esp'}
         self.assertRaises(vpn_validator.IpsecValidationFailure,
                           self.validator.validate_ipsec_policy,
                           self.context, ipsec_policy)
 
+        auth_algorithm = {'auth_algorithm': 'sha384'}
+        self.assertRaises(vpn_validator.IpsecValidationFailure,
+                          self.validator.validate_ipsec_policy,
+                          self.context, auth_algorithm)
+
+        auth_algorithm = {'auth_algorithm': 'sha512'}
+        self.assertRaises(vpn_validator.IpsecValidationFailure,
+                          self.validator.validate_ipsec_policy,
+                          self.context, auth_algorithm)
+
+    def test_validate_ike_policy(self):
+        # Validate IKE Policy auth_algorithm
+
+        auth_algorithm = {'auth_algorithm': 'sha384'}
+        self.assertRaises(vpn_validator.IkeValidationFailure,
+                          self.validator.validate_ike_policy,
+                          self.context, auth_algorithm)
+
+        auth_algorithm = {'auth_algorithm': 'sha512'}
+        self.assertRaises(vpn_validator.IkeValidationFailure,
+                          self.validator.validate_ike_policy,
+                          self.context, auth_algorithm)
+
     def test_defaults_for_ipsec_site_connections_on_update(self):
         """Check that defaults are used for any values not specified."""
         ipsec_sitecon = {}
@@ -484,6 +507,23 @@ class TestIPsecDriverValidation(base.BaseTestCase):
         cidrs = self.validator._get_peer_cidrs(peer_epg)
         self.assertEqual(expected_cidrs, cidrs)
 
+    def test_ipsec_conn_check_peer_cidrs(self):
+        peer_cidrs = ['10.10.10.0/24', '20.20.20.0/24']
+        try:
+            self.validator._check_peer_cidrs(peer_cidrs)
+        except Exception:
+            self.fail("All peer cidrs format should be valid")
+
+    def test_fail_ipsec_conn_peer_cidrs_with_invalid_format(self):
+        peer_cidrs = ['invalid_cidr']
+        self.assertRaises(vpnaas.IPsecSiteConnectionPeerCidrError,
+                          self.validator._check_peer_cidrs,
+                          peer_cidrs)
+        peer_cidrs = ['192/24']
+        self.assertRaises(vpnaas.IPsecSiteConnectionPeerCidrError,
+                          self.validator._check_peer_cidrs,
+                          peer_cidrs)
+
     def test_fail_ipsec_conn_endpoint_group_types(self):
         local_epg = {'id': 'should-be-subnets',
                      'type': v_constants.CIDR_ENDPOINT,
