@@ -16,7 +16,8 @@
 import mock
 
 from neutron import context as n_ctx
-from neutron.plugins.common import constants as nconstants
+from neutron_lib import constants
+from neutron_lib.plugins import directory
 from oslo_utils import uuidutils
 
 from neutron_vpnaas.services.vpn.service_drivers import ipsec as ipsec_driver
@@ -57,13 +58,8 @@ class TestIPsecDriver(base.BaseTestCase):
         l3_agent.host = FAKE_HOST
         plugin = mock.Mock()
         plugin.get_l3_agents_hosting_routers.return_value = [l3_agent]
-        plugin_p = mock.patch('neutron.manager.NeutronManager.get_plugin')
-        get_plugin = plugin_p.start()
-        get_plugin.return_value = plugin
-        service_plugin_p = mock.patch(
-            'neutron.manager.NeutronManager.get_service_plugins')
-        get_service_plugin = service_plugin_p.start()
-        get_service_plugin.return_value = {nconstants.L3_ROUTER_NAT: plugin}
+        directory.add_plugin(constants.CORE, plugin)
+        directory.add_plugin(constants.L3, plugin)
         self.svc_plugin = mock.Mock()
         self.svc_plugin.get_l3_agents_hosting_routers.return_value = [l3_agent]
         self._fake_vpn_router_id = _uuid()
@@ -120,6 +116,7 @@ class TestIPsecDriver(base.BaseTestCase):
         local_endpoints = info.get('local_endpoints', [])
         peer_cidrs = info.get('peer_cidrs', ['40.4.0.0/24', '50.5.0.0/24'])
         peer_id = info.get('peer_id', '30.30.0.0')
+        local_id = info.get('local_id', '')
 
         fake_ikepolicy = FakeSqlQueryObject(id='foo-ike', name='ike-name')
         fake_ipsecpolicy = FakeSqlQueryObject(id='foo-ipsec')
@@ -134,6 +131,7 @@ class TestIPsecDriver(base.BaseTestCase):
         fake_ipsec_conn = FakeSqlQueryObject(id='conn-id',
                                              peer_id=peer_id,
                                              peer_address=peer_address,
+                                             local_id=local_id,
                                              ikepolicy=fake_ikepolicy,
                                              ipsecpolicy=fake_ipsecpolicy,
                                              peer_ep_group_id=peer_epg_id,
@@ -168,7 +166,8 @@ class TestIPsecDriver(base.BaseTestCase):
                                              external_v4_ip=external_ip,
                                              external_v6_ip=None,
                                              subnet_id=subnet_id,
-                                             router_id='foo-router-id')
+                                             router_id='foo-router-id',
+                                             project_id='foo-project-id')
         if local_endpoints:
             fake_vpnservice.subnet = None
         else:
@@ -193,6 +192,7 @@ class TestIPsecDriver(base.BaseTestCase):
         external_ip = '10.0.0.99'
         peer_id = info.get('peer_id', '30.30.0.0')
         peer_cidrs = info.get('peer_cidrs', ['40.4.0.0/24', '50.5.0.0/24'])
+        local_id = info.get('local_id', '')
 
         return {'name': 'foo-vpn',
                 'id': 'foo-vpn-id',
@@ -208,11 +208,14 @@ class TestIPsecDriver(base.BaseTestCase):
                            'network_id': 'foo-net-id'},
                 'subnet_id': 'foo-subnet-id',
                 'external_ip': external_ip,
+                'project_id': 'foo-project-id',
+                'tenant_id': 'foo-project-id',
                 'ipsec_site_connections': [
                     {'id': 'conn-id',
                      'peer_id': peer_id,
                      'external_ip': external_ip,
                      'peer_address': '10.0.0.2',
+                     'local_id': local_id,
                      'ikepolicy': {'id': 'foo-ike',
                                    'name': 'ike-name'},
                      'ipsecpolicy': {'id': 'foo-ipsec'},
@@ -234,6 +237,7 @@ class TestIPsecDriver(base.BaseTestCase):
 
         external_ip = '10.0.0.99'
         peer_id = '30.30.0.0'
+        local_id = info.get('local_id', '')
         return {'name': 'foo-vpn',
                 'id': 'foo-vpn-id',
                 'description': 'foo-vpn-service',
@@ -245,11 +249,14 @@ class TestIPsecDriver(base.BaseTestCase):
                 'subnet': None,
                 'subnet_id': None,
                 'external_ip': external_ip,
+                'project_id': 'foo-project-id',
+                'tenant_id': 'foo-project-id',
                 'ipsec_site_connections': [
                     {'id': 'conn-id',
                      'peer_id': peer_id,
                      'external_ip': external_ip,
                      'peer_address': '10.0.0.2',
+                     'local_id': local_id,
                      'ikepolicy': {'id': 'foo-ike',
                                    'name': 'ike-name'},
                      'ipsecpolicy': {'id': 'foo-ipsec'},
